@@ -577,7 +577,7 @@ class SoftwarePropertiesKDE(SoftwareProperties):
   def show_keys(self):
     self.userinterface.treeview2.clear()
     for key in self.apt_key.list():
-      self.userinterface.treeview2.addTopLevelItem(QTreeWidgetItem([unicode(key, 'UTF-8')]))
+      self.userinterface.treeview2.addTopLevelItem(QTreeWidgetItem([key]))
 
   def on_combobox_update_interval_changed(self, index):
     #FIXME! move to backend
